#!/bin/sh

# This script creates a user named from the "mds_var1" variable with a password from the "mds_var2" variable.
# If used in MDS, set up the workflow variable "mds_var1" to prompt for a full name and "mds_var2" to prompt for a password.
# Add this script to the specified script folder and add the "Resources" folder to the scripts folder at the same level as the script.

# IMPORTANT: This script REQUIRES "mkuser" by Pico Mitchell of Free Geek.
# Download the latest version of mkuser at https://mkuser.sh and place it in the "Resources" folder.

# NOTE: the create user will be an admin.

user_full_name="${mds_var1}" # Full Name will be populated with the contents of mds_var1. Change to a different variable if you want to.
# NOTE: The users Short Name will be automatically generated like macOS does. For example, if the user_full_name is "MDS User", the Short Name will be set to "mdsuser".
user_password="${mds_var2}" # Password will be populated with the contents of mds_var2. Change to a different variable if you want to.
user_uid=602 # The user will have a UID of 602. If you want a different UID, change it to the value you want.

readonly SCRIPT_VERSION='2022.5.12-1'

PATH='/usr/bin:/bin:/usr/sbin:/sbin'

script_name_and_version="\"$(basename "$0")\" version ${SCRIPT_VERSION} on macOS $(sw_vers -productVersion) $(sw_vers -buildVersion)"

echo "Starting ${script_name_and_version}..."

if [ -z "$3" ]; then
	echo 'You must specify 3 args, of which the 3rd one is the target volume. This is the same order for a package installer so the script can be called easily from MDS.'
	exit 1
fi

script_dir="${0%/*}"
mkuser_path="${script_dir}/Resources/mkuser.sh"

if [ ! -r "${mkuser_path}" ]; then
	printf 'The required "%s" file does not exist or is not readable.\nDownload the latest version of mkuser at https://mkuser.sh and place it in the "Resources" folder.\n' "${mkuser_path}"
	exit 1
fi

chmod +x "${mkuser_path}"
echo "${user_password}" | "${mkuser_path}" --full-name "${user_full_name}" --uid "${user_uid}" --stdin-password --admin

echo "Completed ${script_name_and_version}"
