#!/bin/sh
# Thanks to Cameron Stott for this script
# selects version of macOS to install based on known hardware support
# query machine info and separate type, model, submodel numbers. omit other strings containing 'model'
# workflows to run should be named "BigSur", "Catalina", "HighSierra","ElCapitan"

MACHINE_QUERY=$(/usr/sbin/ioreg -c IOPlatformExpertDevice | grep "model" | grep -vE 'bridge|config|number' )
MACHINE_TYPE=$(echo $MACHINE_QUERY | cut -d'=' -f2 | grep -i -o '[a-z]\+')
MACHINE_MODEL=$(echo $MACHINE_QUERY | grep -o '[0-9]\+' | awk '{if(NR==1) print $0}')
SUBMODEL=$(echo $MACHINE_QUERY | grep -o '[0-9]\+' | awk '{if(NR==2) print $0}')
# for a given machine type, evaluate the maximum OS version supported
if [[ "${MACHINE_TYPE}" == "MacBookPro" ]]; then  
    if [ $MACHINE_MODEL -ge 11 ]; then max_macOS="BigSur"
    elif [ $MACHINE_MODEL -ge 9 ]; then max_macOS="Catalina"
    elif [ $MACHINE_MODEL -ge 6 ]; then max_macOS="HighSierra"
    elif [ $MACHINE_MODEL -ge 3 ]; then max_macOS="ElCapitan"
    fi
fi
if [[ "${MACHINE_TYPE}" == "MacBook" ]]; then
    if [ $MACHINE_MODEL -ge 8 ]; then max_macOS="BigSur"
    elif [ $MACHINE_MODEL -ge 6 ]; then max_macOS="HighSierra"
    elif [ $MACHINE_MODEL -ge 5 ]; then max_macOS="ElCapitan"
    fi
fi
if [[ "${MACHINE_TYPE}" == "MacBookAir" ]]; then
    if [ $MACHINE_MODEL -ge 6 ]; then max_macOS="BigSur"
    elif [ $MACHINE_MODEL -ge 5 ]; then max_macOS="Catalina"
    elif [ $MACHINE_MODEL -ge 3 ]; then max_macOS="HighSierra"
    elif [ $MACHINE_MODEL -ge 2 ]; then max_macOS="ElCapitan"
    fi
fi
if [[ "${MACHINE_TYPE}" == "iMac" ]]; then
    if [ $MACHINE_MODEL -ge 15 ]; then max_macOS="BigSur"
    elif [ $MACHINE_MODEL -ge 14 -a $SUBMODEL -eq 4 ]; then max_macOS="BigSur"
    elif [ $MACHINE_MODEL -ge 13 ]; then max_macOS="Catalina"
    elif [ $MACHINE_MODEL -ge 10 ]; then max_macOS="HighSierra"
    elif [ $MACHINE_MODEL -ge 7 ]; then max_macOS="ElCapitan"
    fi
fi
if [[ "${MACHINE_TYPE}" == "Macmini" ]]; then
    if [ $MACHINE_MODEL -ge 7 ]; then max_macOS="BigSur"
    elif [ $MACHINE_MODEL -ge 6 ]; then max_macOS="Catalina"
    elif [ $MACHINE_MODEL -ge 4 ]; then max_macOS="HighSierra"
    elif [ $MACHINE_MODEL -ge 3 ]; then max_macOS="ElCapitan"
    fi
fi
if [[ "${MACHINE_TYPE}" == "MacPro" ]]; then
    if [ $MACHINE_MODEL -ge 6 ]; then max_macOS="BigSur"
    elif [ $MACHINE_MODEL -ge 5 ]; then max_macOS="HighSierra"
    elif [ $MACHINE_MODEL -ge 3 ]; then max_macOS="ElCapitan"
    fi
fi
if [[ "${MACHINE_TYPE}" == "iMacPro" ]]; then
    max_macOS="BigSur"
fi
# return workflow choice key, timeout until execution, volume to target automatically
workflow_autorun_name="$max_macOS"
workflow_autorun_timeout="1"
workflow_autorun_volume="macos"
printf '{"workflow_autorun_name":"%s","workflow_autorun_timeout":"%s","workflow_autorun_volume":"%s"}\n' "$workflow_autorun_name" "$workflow_autorun_timeout" "$workflow_autorun_volume"